==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1CapabilitiesFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public class V1CapabilitiesFluentImpl<A extends V1CapabilitiesFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1CapabilitiesFluent<A>{

    private List<String> add;
    private List<String> drop;

    public V1CapabilitiesFluentImpl(){
    }
    public V1CapabilitiesFluentImpl(V1Capabilities instance){
            this.withAdd(instance.getAdd());

            this.withDrop(instance.getDrop());

    }

    public A addToAdd(int index,String item){
            if (this.add == null) {this.add = new ArrayList<String>();}
            this.add.add(index, item);
            return (A)this;
    }

    public A setToAdd(int index,String item){
            if (this.add == null) {this.add = new ArrayList<String>();}
            this.add.set(index, item); return (A)this;
    }

    public A addToAdd(String... items){
            if (this.add == null) {this.add = new ArrayList<String>();}
            for (String item : items) {this.add.add(item);} return (A)this;
    }

    public A addAllToAdd(Collection<String> items){
            if (this.add == null) {this.add = new ArrayList<String>();}
            for (String item : items) {this.add.add(item);} return (A)this;
    }

    public A removeFromAdd(String... items){
            for (String item : items) {if (this.add!= null){ this.add.remove(item);}} return (A)this;
    }

    public A removeAllFromAdd(Collection<String> items){
            for (String item : items) {if (this.add!= null){ this.add.remove(item);}} return (A)this;
    }

    public List<String> getAdd(){
            return this.add;
    }

    public String getAdd(int index){
            return this.add.get(index);
    }

    public String getFirstAdd(){
            return this.add.get(0);
    }

    public String getLastAdd(){
            return this.add.get(add.size() - 1);
    }

    public String getMatchingAdd(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: add) { if(predicate.apply(item)){return item;} } return null;
    }

    public A withAdd(List<String> add){
            if (this.add != null) { _visitables.removeAll(this.add);}
            if (add != null) {this.add = new ArrayList<String>(); for (String item : add){this.addToAdd(item);}} else { this.add = null;} return (A) this;
    }

    public A withAdd(String... add){
            if (this.add != null) {this.add.clear();}
            if (add != null) {for (String item :add){ this.addToAdd(item);}} return (A) this;
    }

    public Boolean hasAdd(){
            return add != null && !add.isEmpty();
    }

    public A addToDrop(int index,String item){
            if (this.drop == null) {this.drop = new ArrayList<String>();}
            this.drop.add(index, item);
            return (A)this;
    }

    public A setToDrop(int index,String item){
            if (this.drop == null) {this.drop = new ArrayList<String>();}
            this.drop.set(index, item); return (A)this;
    }

    public A addToDrop(String... items){
            if (this.drop == null) {this.drop = new ArrayList<String>();}
            for (String item : items) {this.drop.add(item);} return (A)this;
    }

    public A addAllToDrop(Collection<String> items){
            if (this.drop == null) {this.drop = new ArrayList<String>();}
            for (String item : items) {this.drop.add(item);} return (A)this;
    }

    public A removeFromDrop(String... items){
            for (String item : items) {if (this.drop!= null){ this.drop.remove(item);}} return (A)this;
    }

    public A removeAllFromDrop(Collection<String> items){
            for (String item : items) {if (this.drop!= null){ this.drop.remove(item);}} return (A)this;
    }

    public List<String> getDrop(){
            return this.drop;
    }

    public String getDrop(int index){
            return this.drop.get(index);
    }

    public String getFirstDrop(){
            return this.drop.get(0);
    }

    public String getLastDrop(){
            return this.drop.get(drop.size() - 1);
    }

    public String getMatchingDrop(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: drop) { if(predicate.apply(item)){return item;} } return null;
    }

    public A withDrop(List<String> drop){
            if (this.drop != null) { _visitables.removeAll(this.drop);}
            if (drop != null) {this.drop = new ArrayList<String>(); for (String item : drop){this.addToDrop(item);}} else { this.drop = null;} return (A) this;
    }

    public A withDrop(String... drop){
            if (this.drop != null) {this.drop.clear();}
            if (drop != null) {for (String item :drop){ this.addToDrop(item);}} return (A) this;
    }

    public Boolean hasDrop(){
            return drop != null && !drop.isEmpty();
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1CapabilitiesFluentImpl that = (V1CapabilitiesFluentImpl) o;
            if (add != null ? !add.equals(that.add) :that.add != null) return false;
            if (drop != null ? !drop.equals(that.drop) :that.drop != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1CapabilitiesFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import io.kubernetes.client.fluent.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class V1CapabilitiesFluentImpl<A extends V1CapabilitiesFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1CapabilitiesFluent<A>{

    private List<String> add;
    private List<String> drop;

    public V1CapabilitiesFluentImpl(){
    }
    public V1CapabilitiesFluentImpl(V1Capabilities instance){
            this.withAdd(instance.getAdd());

            this.withDrop(instance.getDrop());

    }

    public A addToAdd(int index,String item){
            if (this.add == null) {this.add = new ArrayList<String>();}
            this.add.add(index, item);
            return (A)this;
    }

    public A setToAdd(int index,String item){
            if (this.add == null) {this.add = new ArrayList<String>();}
            this.add.set(index, item); return (A)this;
    }

    public A addToAdd(String... items){
            if (this.add == null) {this.add = new ArrayList<String>();}
            for (String item : items) {this.add.add(item);} return (A)this;
    }

    public A addAllToAdd(Collection<String> items){
            if (this.add == null) {this.add = new ArrayList<String>();}
            for (String item : items) {this.add.add(item);} return (A)this;
    }

    public A removeFromAdd(String... items){
            for (String item : items) {if (this.add!= null){ this.add.remove(item);}} return (A)this;
    }

    public A removeAllFromAdd(Collection<String> items){
            for (String item : items) {if (this.add!= null){ this.add.remove(item);}} return (A)this;
    }

    public List<String> getAdd(){
            return this.add;
    }

    public String getAdd(int index){
            return this.add.get(index);
    }

    public String getFirstAdd(){
            return this.add.get(0);
    }

    public String getLastAdd(){
            return this.add.get(add.size() - 1);
    }

    public String getMatchingAdd(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: add) { if(predicate.apply(item)){return item;} } return null;
    }

    public Boolean hasMatchingAdd(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: add) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withAdd(List<String> add){
            if (this.add != null) { _visitables.get("add").removeAll(this.add);}
            if (add != null) {this.add = new ArrayList<String>(); for (String item : add){this.addToAdd(item);}} else { this.add = null;} return (A) this;
    }

    public A withAdd(String... add){
            if (this.add != null) {this.add.clear();}
            if (add != null) {for (String item :add){ this.addToAdd(item);}} return (A) this;
    }

    public Boolean hasAdd(){
            return add != null && !add.isEmpty();
    }

    public A addNewAdd(String arg1){
            return (A)addToAdd(new String(arg1));
    }

    public A addNewAdd(StringBuilder arg1){
            return (A)addToAdd(new String(arg1));
    }

    public A addNewAdd(StringBuffer arg1){
            return (A)addToAdd(new String(arg1));
    }

    public A addToDrop(int index,String item){
            if (this.drop == null) {this.drop = new ArrayList<String>();}
            this.drop.add(index, item);
            return (A)this;
    }

    public A setToDrop(int index,String item){
            if (this.drop == null) {this.drop = new ArrayList<String>();}
            this.drop.set(index, item); return (A)this;
    }

    public A addToDrop(String... items){
            if (this.drop == null) {this.drop = new ArrayList<String>();}
            for (String item : items) {this.drop.add(item);} return (A)this;
    }

    public A addAllToDrop(Collection<String> items){
            if (this.drop == null) {this.drop = new ArrayList<String>();}
            for (String item : items) {this.drop.add(item);} return (A)this;
    }

    public A removeFromDrop(String... items){
            for (String item : items) {if (this.drop!= null){ this.drop.remove(item);}} return (A)this;
    }

    public A removeAllFromDrop(Collection<String> items){
            for (String item : items) {if (this.drop!= null){ this.drop.remove(item);}} return (A)this;
    }

    public List<String> getDrop(){
            return this.drop;
    }

    public String getDrop(int index){
            return this.drop.get(index);
    }

    public String getFirstDrop(){
            return this.drop.get(0);
    }

    public String getLastDrop(){
            return this.drop.get(drop.size() - 1);
    }

    public String getMatchingDrop(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: drop) { if(predicate.apply(item)){return item;} } return null;
    }

    public Boolean hasMatchingDrop(io.kubernetes.client.fluent.Predicate<String> predicate){
            for (String item: drop) { if(predicate.apply(item)){return true;} } return false;
    }

    public A withDrop(List<String> drop){
            if (this.drop != null) { _visitables.get("drop").removeAll(this.drop);}
            if (drop != null) {this.drop = new ArrayList<String>(); for (String item : drop){this.addToDrop(item);}} else { this.drop = null;} return (A) this;
    }

    public A withDrop(String... drop){
            if (this.drop != null) {this.drop.clear();}
            if (drop != null) {for (String item :drop){ this.addToDrop(item);}} return (A) this;
    }

    public Boolean hasDrop(){
            return drop != null && !drop.isEmpty();
    }

    public A addNewDrop(String arg1){
            return (A)addToDrop(new String(arg1));
    }

    public A addNewDrop(StringBuilder arg1){
            return (A)addToDrop(new String(arg1));
    }

    public A addNewDrop(StringBuffer arg1){
            return (A)addToDrop(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1CapabilitiesFluentImpl that = (V1CapabilitiesFluentImpl) o;
            if (add != null ? !add.equals(that.add) :that.add != null) return false;
            if (drop != null ? !drop.equals(that.drop) :that.drop != null) return false;
            return true;
    }




}
